/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Path2D;

import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;



/**
 * This test renders various quadratic curves using identity transformation
 * matrix. Quadratic curves are constructed using Path class.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.PATH)
@PathVariant(PathVariants.QUADRATIC_CURVE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class NormalQuadraticCurvesAsPaths extends GfxTest
{

    /**
     * Step between curves drawn by different colors onto the same image.
     */
    private static final int OFFSET_STEP = 20;

    /**
     * Draw crosses at the both end points and control point of quadratic curve.
     * 
     * @param graphics
     *            graphics canvas
     * @param x1
     *            first quadratic curve x coordinate
     * @param y1
     *            first quadratic curve y coordinate
     * @param x2
     *            second quadratic curve x coordinate
     * @param y2
     *            second quadratic curve y coordinate
     * @param x3
     *            third quadratic curve x coordinate
     * @param y3
     *            third quadratic curve x coordinate
     */
    private void drawCrossesAtControlPoints(Graphics2D graphics, int x1, int y1, int x2, int y2, int x3, int y3)
    {
        drawCross(graphics, x1, y1);
        drawCross(graphics, x2, y2);
        drawCross(graphics, x3, y3);
    }

    /**
     * Draw crosses at the both end points and control point of quadratic curve.
     * 
     * @param graphics
     *            graphics canvas
     * @param width
     *            test image width
     * @param height
     *            test image height
     */
    private void drawCrossesAtControlPoints(Graphics2D graphics, int width, int height)
    {
        // get curve coordinates
        int x1 = CommonPathsGenerator.computeQuadraticPathX1(width);
        int y1 = CommonPathsGenerator.computeQuadraticPathY1();
        int x2 = CommonPathsGenerator.computeQuadraticPathX2(width);
        int y2 = CommonPathsGenerator.computeQuadraticPathY2(height);
        int x3 = CommonPathsGenerator.computeQuadraticPathX3(width);
        int y3 = CommonPathsGenerator.computeQuadraticPathY3();
        drawCrossesAtControlPoints(graphics, x1, y1, x2, y2, x3, y3);
    }

    /**
     * Draw quadratic curve contained in the path onto canvas specified by
     * Graphics2D class.
     * 
     * @param graphics
     *            graphics canvas
     * @param width
     *            canvas width
     * @param height
     *            canvas height
     * @param path
     *            curve contained in the path to be drawn
     * @param color
     *            curve color or null when Color.BLACK can be used.
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult drawPath(Graphics2D graphics, int width, int height, Path2D path, Color color)
    {
        // set the specified color
        graphics.setColor(color == null ? Color.BLACK : color);

        // draw QuadCurve2D
        graphics.draw(path);

        // draw crosses at control points
        drawCrossesAtControlPoints(graphics, width, height);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Draw quadratic curve contained in the path onto canvas specified by
     * Graphics2D class.
     * 
     * @param graphics
     *            graphics canvas
     * @param width
     *            canvas width
     * @param height
     *            canvas height
     * @param path
     *            curve contained in the path to be drawn
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult drawPath(Graphics2D graphics, int w, int h, Path2D path)
    {
        return drawPath(graphics, w, h, path, Color.BLACK);
    }

    /**
     * Draw set of quadratic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawPathWithVariousColorsFloat(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width = image.getWidth();
        int height = image.getHeight();
        
        // curve colors
        Color[] colors = ColorPalette.getColors();

        // offset counter
        int offset = 0;

        // Draw each curve with different color.
        for (Color color : colors)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createQuadraticPathFloat(width, height, offset);

            // set the specified color
            graphics.setColor(color);

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Draw set of quadratic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawPathWithVariousColorsDouble(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width = image.getWidth();
        int height = image.getHeight();
        
        // curve colors
        Color[] colors = ColorPalette.getColors();

        // offset counter
        int offset = 0;

        // Draw each curve with different color.
        for (Color color : colors)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createQuadraticPathDouble(width, height, offset);

            // set the specified color
            graphics.setColor(color);

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Draw set of quadratic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawPathWithVariousTransparencyFloat(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width = image.getWidth();
        int height = image.getHeight();
        
        // offset counter
        int offset = 0;

        // Draw each curve with transparency
        for (int transparency = 0; transparency < 16; transparency++)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createQuadraticPathFloat(width, height, offset);

            // set the specified color
            graphics.setColor(new Color(0f, 0f, 0f, transparency / 16f));

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Draw set of quadratic curves onto canvas specified by Graphics2D class.
     * Curves are drawn using various transparency.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics canvas
     */
    private void drawPathWithVariousTransparencyDouble(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width = image.getWidth();
        int height = image.getHeight();
        
        // offset counter
        int offset = 0;

        // Draw each curve with transparency
        for (int transparency = 0; transparency < 16; transparency++)
        {
            // create new path
            Path2D path = CommonPathsGenerator.createQuadraticPathDouble(width, height, offset);

            // set the specified color
            graphics.setColor(new Color(0f, 0f, 0f, transparency / 16f));

            // draw QuadCurve2D
            graphics.draw(path);

            // move next curve down
            offset += OFFSET_STEP;
        }
    }

    /**
     * Create quadratic cube and draw it.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult createAndDrawPathFloat(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width =  image.getWidth();
        int height =  image.getHeight();

        // create new path
        Path2D path = CommonPathsGenerator.createQuadraticPathFloat(width, height);

        // draw path
        return drawPath(graphics, width, height, path);
    }

    /**
     * Create quadratic cube and draw it.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult createAndDrawPathDouble(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width =  image.getWidth();
        int height =  image.getHeight();

        // create new path
        Path2D path = CommonPathsGenerator.createQuadraticPathDouble(width, height);

        // draw path
        return drawPath(graphics, width, height, path);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBasicQuadCurveFloat(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width = image.getWidth();
        int height = image.getHeight();

        // create new path
        Path2D path = CommonPathsGenerator.createQuadraticPathFloat(width, height);

        // draw path
        return drawPath(graphics, width, height, path);
    }

    /**
     * Test if quadratic curve created by Path2D.Double() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBasicQuadCurveDouble(TestImage image, Graphics2D graphics)
    {
        // calculate image dimensions
        int width = image.getWidth();
        int height = image.getHeight();

        // create new path
        Path2D path = CommonPathsGenerator.createQuadraticPathDouble(width, height);

        // draw path
        return drawPath(graphics, width, height, path);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and butt
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_BUTT);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and butt
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_BUTT);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and round
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_ROUND);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_ROUND);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and square
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_SQUARE);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with zero pixels wide stroke and square
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testZeroStrokeCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics, BasicStroke.CAP_SQUARE);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with 10 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with 10 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 10 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testThickStrokeCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with 30 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is to be drawn with 30 pixels wide stroke and default
     * caps.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathFloat(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is to be drawn with 30 pixels wide stroke and the curve caps is set
     * to CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testExtraThickStrokeCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // create quadratic path and draw it
        return createAndDrawPathDouble(image, graphics);
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is drawn using different colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsBasicStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered
     * correctly. Curve is drawn using different colors.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsBasicStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics); 

        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics); 

        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsExtraThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics); 

        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Double() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsExtraThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics); 

        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using zero pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsZeroThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics); 

        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using zero pixel wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsZeroThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics); 

        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke
     * using CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsButtFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke
     * using CAP_BUTT.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsButtDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke
     * using CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsRoundFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke
     * using CAP_ROUND.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsRoundDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke
     * using CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsSquareFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawPathWithVariousColorsFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixel wide stroke
     * using CAP_SQUARE.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testColorsCapsSquareDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // draw set of curves using test color palette
        drawPathWithVariousColorsDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using default stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyBasicStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using different transparency
        drawPathWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using default stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyBasicStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // draw set of curves using different transparency
        drawPathWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixels wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // draw set of curves using different transparency
        drawPathWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 10 pixels wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 10 pixels wide stroke
        CommonRenderingStyles.setStrokeThickWidth(graphics, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL);

        // draw set of curves using different transparency
        drawPathWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 30 pixels wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyExtraThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // draw set of curves using different transparency
        drawPathWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using 30 pixels wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyExtraThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set 30 pixels wide stroke
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics);

        // draw set of curves using different transparency
        drawPathWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using zero pixels wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyZeroThickStrokeFloat(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // draw set of curves using different transparency
        drawPathWithVariousTransparencyFloat(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if quadratic curve created by Path2D.Float() is rendered correctly.
     * Curve is drawn using different colors and using zero pixels wide stroke.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testTransparencyZeroThickStrokeDouble(TestImage image, Graphics2D graphics)
    {
        // set zero pixels wide stroke
        CommonRenderingStyles.setStrokeZeroThick(graphics);

        // draw set of curves using different transparency
        drawPathWithVariousTransparencyDouble(image, graphics);

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new NormalQuadraticCurvesAsPaths().runTestSuite(args);
    }
}
